***********************
Technical specification
***********************

.. toctree::
   :maxdepth: 2
   :titlesonly:

   Objective
   Features <features>
   Technology
   Database schema <DatabaseSchema>
   Urls <Urls>
   Menu
   Content/index
   Admin panel/index
   UsefulLinks
